==> enterprisemodules-ora_config-3.20.0.tar.gz: enterprisemodules-ora_config-3.20.0/lib/puppet/provider/ora_service/oracle12.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/oracle/commands'
require 'easy_type'

Puppet::Type.type(:ora_service).provide(:oracle12) do
  include EasyType::Provider
  include Puppet_X::EnterpriseModules::Oracle::Commands
  include Puppet_X::EnterpriseModules::Oracle::Settings

  confine :exists => settings_file
  confine :feature => :oracle_running
  confine :feature => :oracle12

  desc 'Manage Oracle services using srvctl syntax for Oracle 12 provider.'

  mk_resource_methods

  # aq_ha_notifications
  def apply_aq_ha_notifications(value)
    "-notification #{value}"
  end

  # available_instances
  def create_available_instances(value)
    "-available #{value.join(',')}"
  end

  def update_available_instances(value)
    "-available #{value.join(',')} -modifyconfig"
  end

  # clb_goal
  def apply_clb_goal(value)
    "-clbgoal #{value}"
  end

  # commit_outcome
  def apply_commit_outcome(value)
    "-commit_outcome #{value}"
  end

  # drain_timeout
  def apply_drain_timeout(value)
    "-drain_timeout #{value}"
  end

  # dtp
  def apply_dtp(value)
    "-dtp #{value.to_s.upcase}"
  end

  # failover_delay
  def apply_failover_delay(value)
    "-failoverdelay #{value}"
  end

  # failover_method
  def apply_failover_method(value)
    "-failovermethod #{value}"
  end

  # failover_restore
  def apply_failover_restore(value)
    "-failover_restore #{value}"
  end

  # failover_retries
  def apply_failover_retries(value)
    "-failoverretry #{value}"
  end

  # failover_type
  def apply_failover_type(value)
    "-failovertype #{value}"
  end

  # lb_advisory
  def apply_lb_advisory(value)
    "-rlbgoal #{value}"
  end

  # management_policy
  def apply_management_policy(value)
    "-policy #{value}"
  end

  # network_number
  def apply_network_number(value)
    "-netnum #{value}"
  end

  # preferred_instances
  def create_preferred_instances(value)
    "-preferred #{value.join(',')}"
  end

  def update_preferred_instances(value)
    "-preferred #{value.join(',')} -modifyconfig"
  end

  # replay_init_time
  def apply_replay_init_time(value)
    "-replay_init_time #{value}"
  end

  # retention
  def apply_retention(value)
    "-retention #{value}"
  end

  # server_pool
  def apply_server_pool(value)
    "-serverpool #{value.join(',')}"
  end

  # service_role
  def apply_service_role(value)
    "-role #{value}"
  end

  # session_state
  def apply_session_state(value)
    "-session_state #{value}"
  end

  # stopoption
  def apply_stopoption(value)
    "-stopoption #{value}"
  end

  # taf_policy
  def apply_taf_policy(value)
    "-tafpolicy #{value}"
  end
end

==> enterprisemodules-ora_config-3.22.2.tar.gz: enterprisemodules-ora_config-3.22.2/lib/puppet/provider/ora_service/oracle12.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/oracle/commands'
require 'easy_type'

Puppet::Type.type(:ora_service).provide(:oracle12) do
  include EasyType::Provider
  include PuppetX::EnterpriseModules::Oracle::Commands
  include PuppetX::EnterpriseModules::Oracle::Settings

  confine :exists => settings_file
  confine :feature => :oracle_running
  confine :feature => :oracle12

  desc 'Manage Oracle services using srvctl syntax for Oracle 12 provider.'

  mk_resource_methods

  # aq_ha_notifications
  def apply_aq_ha_notifications(value)
    "-notification #{value}"
  end

  # available_instances
  def create_available_instances(value)
    "-available #{value.join(',')}"
  end

  def update_available_instances(value)
    "-available #{value.join(',')} -modifyconfig"
  end

  # clb_goal
  def apply_clb_goal(value)
    "-clbgoal #{value}"
  end

  # commit_outcome
  def apply_commit_outcome(value)
    "-commit_outcome #{value}"
  end

  # drain_timeout
  def apply_drain_timeout(value)
    "-drain_timeout #{value}"
  end

  # dtp
  def apply_dtp(value)
    "-dtp #{value.to_s.upcase}"
  end

  # failover_delay
  def apply_failover_delay(value)
    "-failoverdelay #{value}"
  end

  # failover_method
  def apply_failover_method(value)
    "-failovermethod #{value}"
  end

  # failover_restore
  def apply_failover_restore(value)
    "-failover_restore #{value}"
  end

  # failover_retries
  def apply_failover_retries(value)
    "-failoverretry #{value}"
  end

  # failover_type
  def apply_failover_type(value)
    "-failovertype #{value}"
  end

  # lb_advisory
  def apply_lb_advisory(value)
    "-rlbgoal #{value}"
  end

  # management_policy
  def apply_management_policy(value)
    "-policy #{value}"
  end

  # network_number
  def apply_network_number(value)
    "-netnum #{value}"
  end

  # preferred_instances
  def create_preferred_instances(value)
    "-preferred #{value.join(',')}"
  end

  def update_preferred_instances(value)
    "-preferred #{value.join(',')} -modifyconfig"
  end

  # replay_init_time
  def apply_replay_init_time(value)
    "-replay_init_time #{value}"
  end

  # retention
  def apply_retention(value)
    "-retention #{value}"
  end

  # server_pool
  def apply_server_pool(value)
    "-serverpool #{value.join(',')}"
  end

  # service_role
  def apply_service_role(value)
    "-role #{value}"
  end

  # session_state
  def apply_session_state(value)
    "-session_state #{value}"
  end

  # stopoption
  def apply_stopoption(value)
    "-stopoption #{value}"
  end

  # taf_policy
  def apply_taf_policy(value)
    "-tafpolicy #{value}"
  end
end
